@@ -1,3 +1,9 @@
+#
+#     Perl DateTime extension for computing the dates for Easter and related feasts
+#     Copyright (C) 2003-2004, 2015 Rick Measham and Jean Forget
+#
+#     See the license in the embedded documentation below.
+#
 package DateTime::Event::Easter;
 use DateTime;
 use DateTime::Set;
@@ -5,6 +11,7 @@ use Carp;
 use Params::Validate qw( validate SCALAR BOOLEAN OBJECT );
 
 use strict;
+use warnings;
 use vars qw(
     $VERSION @ISA @EXPORT @EXPORT_OK 
 );
@@ -14,20 +21,37 @@ require Exporter;
 @ISA = qw(Exporter);
 
 @EXPORT_OK = qw(easter);
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 sub new {
     my $class = shift;
     my %args  = validate( @_,
                     {   easter  => { type => SCALAR, default=>'western', optional=>1, regex => qr/^(western|eastern)$/i },
                         day     => { type => SCALAR, default=>'sunday', optional=>1 },
-						as		=> { type => SCALAR, default=>'point', optional=>1 },
+                        as      => { type => SCALAR, default=>'point', optional=>1 },
                     }
                 );
     
     my %self;
     my $offset;
-    if ($args{day} =~/^palm/i) {
+    if ($args{day} =~/^fat/i) {
+        $offset = -47;
+    }
+    elsif ($args{day} =~/^ash/i) {
+        # First day of lent. Lent lasts for 40 days, excluding sundays.
+        # This translates to a 46-day duration, including sundays.
+        $offset = -46;
+    }
+    elsif ($args{day} =~/^ascension/i) {
+        $offset = 39;
+    }
+    elsif ($args{day} =~/^pentecost/i) {
+        $offset = 49;
+    }
+    elsif ($args{day} =~/^trinity/i) {
+        $offset = 56;
+    }
+    elsif ($args{day} =~/^palm/i) {
         $offset = -7;
     } elsif ($args{day} =~/saturday/i) {
         $offset = -1;
@@ -46,11 +70,11 @@ sub new {
     if ($self{easter} eq 'eastern') {
         require DateTime::Calendar::Julian;
     }
-	
-	# Set to return points or spans
-	die("Argument 'as' must be 'point' or 'span'.") unless $args{as}=~/^(point|span)s?$/i;
-	$self{as} = lc $1;
-	
+
+    # Set to return points or spans
+    die("Argument 'as' must be 'point' or 'span'.") unless $args{as}=~/^(point|span)s?$/i;
+    $self{as} = lc $1;
+
     return bless \%self, $class;
     
 }
@@ -285,20 +309,19 @@ sub eastern_easter {
     return DateTime::Calendar::Julian->new(year=>$year, month=>$month, day=>$day);
 }
 
-
-
-sub _floor {
-    my $x  = shift;
-    my $ix = int $x;
-    if ($ix <= $x) {
-        return $ix;
-    } else {
-        return $ix - 1;
-    }
-}
-
-1;
+# Ending a module with an unspecified number, which could be zero, is wrong.
+# Therefore the custom of ending a module with a boring "1".
+# Instead of that, end it with some verse.
+q{
+Il reviendra  Pques, mironton mironton mirontaine,
+Il reviendra  Pques
+Ou  la Trinit.
+Ou  la Trinit...
+};
 __END__
+
+=encoding iso-8859-1
+
 =head1 NAME
 
 DateTime::Event::Easter - Returns Easter events for DateTime objects
@@ -330,12 +353,13 @@ DateTime::Event::Easter - Returns Easter events for DateTime objects
   $palm_sunday = DateTime::Event::Easter->new(day=>'Palm Sunday');
 
 
-  $dt2 = DateTime->new( year   => 2060,
-                        month  => 4,
-                        day    => 30,
+  $dt2 = DateTime->new( year   => 2006,
+                        month  =>    4,
+                        day    =>   30,
                       );
   
-  @set = $palm_sunday->as_list(from=>$dt, to=>$dt2, inclusive=>1);
+  $set  = $palm_sunday->as_set (from=>$dt, to=>$dt2, inclusive=>1);
+  @list = $palm_sunday->as_list(from=>$dt, to=>$dt2, inclusive=>1);
   # Sun, 13 Apr 2003 00:00:00 UTC
   # Sun, 04 Apr 2004 00:00:00 UTC
   # Sun, 20 Mar 2005 00:00:00 UTC
@@ -343,7 +367,7 @@ DateTime::Event::Easter - Returns Easter events for DateTime objects
   
   $datetime_set = $palm_sunday->as_set;
   # A set of every Palm Sunday ever. See C<DateTime::Set> for more information.
-  
+
 =head1 DESCRIPTION
 
 The DateTime::Event::Easter module returns Easter events for DateTime
@@ -351,10 +375,11 @@ objects. From a given datetime, it can tell you the previous, the
 following and the closest Easter event. The 'is' method will tell you if
 the given DateTime is an Easter Event.
 
-Easter Events can be Palm Sunday, Maundy Thursday, Good Friday, Black
-Saturday and Easter Sunday. If that's not enough, the module will also
-accept an offset so you can get the date for Pentecost (49 days after
-Easter Sunday) by passing 49.
+Easter Events can be Fat Tuesday, Ash Wednesday, Palm Sunday, Maundy
+Thursday, Good Friday, Black Saturday, Easter Sunday, Ascension,
+Pentecost and Trinity Sunday. If that's not enough, the module will
+also accept an offset so you can get the date for Quasimodo (the next
+sunday after Easter Sunday) by passing 7.
 
 
 =head1 BACKGROUND
@@ -365,7 +390,7 @@ March 21st. Easter Sunday is never on the full moon. Thus the earliest
 Easter can be is March 22nd.
 
 In the orthodox world, although they now use the Gregorian Calendar
-rather than the Julian, they still take the first full moon after the
+rather than the Julian, they still take the first full moon on or after the
 Julian March 21st. As the Julian calendar is slowly getting further and
 further out of sync with the Gregorian, the first full moon after this
 date can be a completely different one than for the western Easter. This
@@ -384,11 +409,11 @@ DateTime::Event::Easter understands two calculations for Easter. For
 simplicity we've called them 'western' and 'eastern'.
 
 Western Easter is the day celebrated by the Catholic and Protestant
-churches. It falls on the first Sunday on or after the the first Full
-Moon after March 21st.
+churches. It falls on the first Sunday after the first Full
+Moon on or after March 21st.
 
 Eastern Easter, as celebrated by the Eastern Orthodox Churches similarly
-falls on the first Sunday on or after the the first Full Moon after
+falls on the first Sunday after the first Full Moon on or after
 March 21st. However Eastern Easter uses March 21st in the Julian
 Calendar.
 
@@ -398,8 +423,8 @@ specifically ask for Eastern.
 
 If this parameter is not supplied, the western Easter will be used.
 
-=item * day => ([Easter Sunday]|Palm Sunday|Maundy Thursday|Good
-Friday|Black Saturday|I<n>)
+=item * day => ([Easter Sunday]|Palm Sunday|Maundy Thursday|Good Friday|Black
+Saturday|Fat Tuesday|Ash Wednesday|Ascension|Pentecost|Trinity Sunday|I<n>)
 
 When constructed with a day parameter, the method can return associated
 Easter days other than Easter Sunday. The constructor also allows an
@@ -411,14 +436,14 @@ Easter Sunday (which is the churches' official day for 'Easter', think
 of it a 'Easter Day' if you want)
 
 This parameter also allows the following abreviations: day =>
-([Sunday]|Palm|Thursday|Friday|Saturday)
+([Sunday]|Palm|Thursday|Friday|Saturday|Fat|Ash|Ascension|Pentecost|Trinity)
 
 =item * as => ([point]|span)
 
 By default, all returns are single points in time. Namely they are the
 moment of midnight for the day in question. If you want Easter 2003 then
 you actually get back midnight of April 20th 2003. If you specify 
-C<as => 'span'> in your constructor, you'll now receive 24 hour spans
+C<< as => 'span' >> in your constructor, you'll now receive 24 hour spans
 rather than moments (or 'points'). I<See also the C<as_span> and C<as_point>
 methods below>
 
@@ -474,7 +499,7 @@ Returns a DateTime::Set of Easter Events.
 In the past this method used the same syntax as 'as_list' above. However
 we now allow both the above syntax as well as the full options allowable
 when creating sets with C<DateTime::Set>. This means you can call
-C<$datetime_set = $palm_sunday->as_set;> and it will return a 
+C<< $datetime_set = $palm_sunday->as_set; >> and it will return a 
 C<DateTime::Set> of all Palm Sundays. See C<DateTime::Set> for more information.
 
 
@@ -532,6 +557,8 @@ Bugs should be reported through rt.cpan.org.
 
 Rick Measham <rickm@cpan.org>
 
+Co-maintainer Jean Forget <jforget@cpan.org>
+
 =head2 CREDITS
 
 Much help from the DateTime mailing list, especially from:
@@ -544,16 +571,39 @@ B<Dave Rolsky> - who picked nits, designed DateTime itself and leads the project
 
 B<Martin Hasch> - who pointed out the posibility of memory leak with an early beta
 
+B<Joe Orost> and B<Andreas Knig> - for RT tickets about the POD documentation
+
+B<Frank Wiegand> and B<Slaven Rezic> - for patches fixing the POD problems
+
 =head2 COPYRIGHT
 
-(c) Copyright  2003 Rick Measham. All rights reserved. This program is
-free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
+(c) Copyright 2003, 2004, 2015 Rick Measham and Jean Forget. All
+rights reserved. This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself: GNU
+Public License version 1 or later and Perl Artistic License.
 
-The full text of the license can be found in the LICENSE file included
-with this module.
+The full text of the license can be found in the F<LICENSE> file
+included with this module or at
+L<http://www.perlfoundation.org/artistic_license_1_0> and
+L<http://www.gnu.org/licenses/gpl-1.0.html>.
+
+Here is the summary of GPL:
+
+This program is  free software; you can redistribute  it and/or modify
+it under the  terms of the GNU General Public  License as published by
+the Free  Software Foundation; either  version 1, or (at  your option)
+any later version.
+
+This program  is distributed in the  hope that it will  be useful, but
+WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
+MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+General Public License for more details.
+
+You  should have received  a copy  of the  GNU General  Public License
+along with this program; if not, see <http://www.gnu.org/licenses/> or
+write to the Free Software Foundation, Inc., L<http://fsf.org>.
 
 =head2 SEE ALSO
 
-L<DateTime>, L<DateTime::Calendar::Easter>, perl(1),
+L<DateTime>, L<DateTime::Calendar::Julian>, perl(1),
 http://datetime.perl.org.
